@@ -28,7 +28,7 @@ from pysqueezecenter.server import Server
 from pysqueezecenter.player import Player
 
 app_path = os.environ['HOME'] + '/.squeezecontrol/'
-app_version = '0.1.0'
+app_version = '0.1.1'
 
 def format_seconds(seconds):
 	seconds = int(seconds)
@@ -95,8 +95,9 @@ class PlayerWindow(QMainWindow):
 		self.track_info_label.setText(self.track_info)
 		self.elapsed_label.setText(format_seconds(self.elapsed))
 		self.remaining_label.setText(format_seconds(self.remaining))
-		position = int(self.elapsed / self.duration * 1000)
-		self.progress_bar.setValue(position)
+		if self.can_skip_forwards():
+			position = int(self.elapsed / self.duration * 1000)
+			self.progress_bar.setValue(position)
 		self.update()
 	
 	def render(self):
@@ -122,8 +123,8 @@ class PlayerWindow(QMainWindow):
 		self.remaining_label = QLabel('')
 		hbox.addWidget(self.remaining_label)
 		if not self.can_skip_forwards():
-			self.progress_bar.setVisible(false)
-			self.remaining_label.setVisible(false)
+			self.progress_bar.setVisible(False)
+			self.remaining_label.setVisible(False)
 		vbox.addWidget(time)
 		
 		# Main controls
@@ -256,7 +257,7 @@ class AboutWindow(QMainWindow):
 	def render(self):
 		container = QWidget()
 		vbox = QVBoxLayout(container)
-		label = QLabel('This version of SqueezeControl was made while listening to Filth.fm and Radiohead. A huge shoutout to JingleManSweep who made the pysqueezecenter wrapper library for Python. Also thanks to Dag Liodden -- developer of SqueezeControl for Android -- for letting me use the name "SqueezeControl".\n\nCopyright 2010, 2011 JingleManSweep and Mikkel Munch Mortensen. Released under the terms of the GNU General Public License version 3.')
+		label = QLabel('This version of SqueezeControl was made while listening to nothing. A huge shoutout to JingleManSweep who made the pysqueezecenter wrapper library for Python. Also thanks to Dag Liodden -- developer of SqueezeControl for Android -- for letting me use the name "SqueezeControl".\n\nCopyright 2010, 2011 JingleManSweep and Mikkel Munch Mortensen. Released under the terms of the GNU General Public License version 3.')
 		label.setWordWrap(True)
 		vbox.addWidget(label)
 		
